@@ -1,6 +1,6 @@
 package Morpheus::Bootstrap::Extra;
 BEGIN {
-  $Morpheus::Bootstrap::Extra::VERSION = '0.37_01';
+  $Morpheus::Bootstrap::Extra::VERSION = '0.32';
 }
 use strict;
 use warnings;
@@ -9,6 +9,7 @@ use warnings;
 
 use Morpheus::Plugin::Env;
 use Morpheus::Plugin::File;
+use Morpheus::Plugin::Core;
 
 use Morpheus::Plugin::Simple;
 
@@ -21,6 +22,11 @@ sub new {
         "morpheus" => {
             "plugins" => {
 
+                Core => {
+                    priority => 20,
+                    object => Morpheus::Plugin::Core->new(),
+                },
+
                 File => {
                     priority => 30,
                     object => Morpheus::Plugin::File->new(),
@@ -47,7 +53,7 @@ Morpheus::Bootstrap::Extra - extra plugins - Env and File
 
 =head1 VERSION
 
-version 0.37_01
+version 0.32
 
 =head1 AUTHOR
 
