@@ -1,6 +1,6 @@
 package Morpheus::Utils;
 BEGIN {
-  $Morpheus::Utils::VERSION = '0.37_01';
+  $Morpheus::Utils::VERSION = '0.32';
 }
 use strict;
 
@@ -10,7 +10,7 @@ sub normalize ($);
 sub adjust ($$);
 sub merge ($$;$);
 
-use base qw(Exporter);
+use parent qw(Exporter);
 our @EXPORT = qw(normalize merge adjust);
 
 use Symbol qw(gensym);
@@ -23,7 +23,8 @@ sub normalize ($) {
     my $result = { %$data };
     for my $key ( keys %$data) {
         my @keys = @{key($key)};
-        next if @keys == 1 and $keys[0] eq $key; # "/a//" -> "a"
+        next if @keys == 1;
+
         my $value = delete $result->{$key};
         my $p = my $patch = {};
         $p = $p->{$_} = {} for splice @keys, 0, -1;
@@ -110,7 +111,7 @@ Morpheus::Utils - some common functions which don't fit anywhere else
 
 =head1 VERSION
 
-version 0.37_01
+version 0.32
 
 =head1 AUTHOR
 
